function updateCheckInterval(minutes) {
    currentIntervalMinutes = minutes;
    // עדכון או יצירת התראה חדשה
    chrome.alarms.clear('checkNotifications', () => {
        chrome.alarms.create('checkNotifications', {
            periodInMinutes: minutes,
            delayInMinutes: minutes  // התראה ראשונה תתרחש אחרי המרווח הראשון
        });
    });
}

chrome.runtime.onMessage.addListener((request, sender, sendResponse) => {
    if (request.action === "fetchNotifications") {
        fetch(request.url)
            .then(response => response.json())
            .then(data => sendResponse({ data: data }))
            .catch(error => sendResponse({ error: error.toString() }));
        return true;
    } else if (request.action === "updateCheckInterval") {
        updateCheckInterval(request.interval);
    }
});


async function shouldShowPopup(hasChanges) {
    if (!hasChanges) return false;

    const muteState = await chrome.storage.local.get('muteUntil');
    if (muteState.muteUntil) {
        const muteUntil = new Date(muteState.muteUntil);
        if (muteUntil > new Date()) {
            return false;
        }
    }
    return true;
}


function areNotificationsChanged(oldState, newState) {
    console.log('Comparing states:', { oldState, newState });

    // אם אין מצב קודם, נחשיב כשינוי רק אם יש התראות חדשות
    if (!oldState) return newState.totalCount > 0;

    // בדיקה אם השתנה מספר כולל של התראות
    if (oldState.totalCount !== newState.totalCount) {
        console.log('Total count changed');
        return true;
    }

    // יצירת סט של כל האתרים (מהישן והחדש)
    const allSites = new Set([
        ...Object.keys(oldState.siteNotifications),
        ...Object.keys(newState.siteNotifications)
    ]);

    // השוואת הערכים עבור כל אתר
    for (const site of allSites) {
        const oldCount = oldState.siteNotifications[site] || 0;
        const newCount = newState.siteNotifications[site] || 0;

        if (oldCount !== newCount) {
            console.log(`Count changed for ${site}: ${oldCount} -> ${newCount}`);
            return true;
        }
    }

    console.log('No changes detected');
    return false;
}

async function checkNotificationsBackground() {
    console.log('checkNotificationsBackground', new Date().toLocaleString());

    let totalUnreadCount = 0;
    let siteNotifications = {};

    let sites = await new Promise(resolve => {
        chrome.storage.sync.get('sites', data => {
            resolve(data.sites || [
                { url: 'https://tchumim.com', name: 'תחומים', enabled: true },
                { url: 'https://mitmachim.top', name: 'מתמחים', enabled: true },
                { url: 'https://f2.freeivr.co.il', name: 'פורום ימות המשיח', enabled: true },
                { url: 'https://forum-office.co.il', name: 'פורום אופיס', enabled: true },
                { url: 'https://forum.netfree.link', name: 'פורום נטפרי', enabled: true },
                { url: 'https://forum.safera.co.il', name: 'פורום סייפר', enabled: true },
                { url: 'https://rechavimzelaze.ovh', name: 'רכבים זה לזה', enabled: true }
            ]);
        });
    });

    const enabledSites = sites.filter(site => site.enabled);

    for (const site of enabledSites) {
        try {
            const response = await fetch(`${site.url}/api/notifications`);
            const data = await response.json();

            if (!data.status || data.status.code !== "not-authorised") {
                const unreadCount = data.notifications.filter(n => !n.read).length;
                totalUnreadCount += unreadCount;
                siteNotifications[site.name] = unreadCount;
            }
        } catch (error) {
            console.error(`Error checking ${site.name}:`, error);
            siteNotifications[site.name] = 0;
        }
    }

    // קריאת המצב הקודם מהאחסון
    const oldState = await new Promise(resolve => {
        chrome.storage.local.get('notificationsState', data => {
            resolve(data.notificationsState);
        });
    });

    // יצירת מצב חדש
    const newState = {
        totalCount: totalUnreadCount,
        siteNotifications: siteNotifications,
        lastChecked: new Date().toISOString()
    };

    const hasChanges = areNotificationsChanged(oldState, newState);
    const shouldPopup = await shouldShowPopup(hasChanges);
    console.log('hasChanges: ' + hasChanges);
    console.log('shouldPopup: ' + shouldPopup);

    try {
        if (totalUnreadCount > 0) {
            chrome.action.setBadgeText({ text: totalUnreadCount.toString() });
            chrome.action.setBadgeBackgroundColor({ color: '#FF0000' });

            if (shouldPopup) {
                chrome.windows.getAll({ populate: true }, async (windows) => {
                    const popupExists = windows.some(window =>
                        window.type === 'popup' && window.tabs.some(tab =>
                            tab.url && tab.url.includes(chrome.runtime.id)
                        )
                    );

                    if (!popupExists) {
                        try {
                            await chrome.action.openPopup();
                        } catch (error) {
                            let message = 'התראות חדשות:\n';
                            for (const [site, count] of Object.entries(siteNotifications)) {
                                if (count > 0) {
                                    message += `${site}: ${count} התראות\n`;
                                }
                            }

                            chrome.notifications.create('newNotifications', {
                                type: 'basic',
                                iconUrl: 'icons/icon48.png',
                                title: 'התראות חדשות',
                                message: message,
                                priority: 2,
                                requireInteraction: true
                            });
                        }
                    }
                });
            }
        } else {
            chrome.action.setBadgeText({ text: '' });
        }

        chrome.storage.local.set({ notificationsState: newState });

    } catch (error) {
        console.error('Error in showing notification:', error);
    }
}



function startBackgroundCheck() {
    chrome.storage.sync.get('checkIntervalMinutes', function (data) {
        const interval = data.checkIntervalMinutes || 5;
        currentIntervalMinutes = interval;

        // בדיקה ראשונית מיידית
        checkNotificationsBackground();

        // הגדרת בדיקות תקופתיות באמצעות alarms
        updateCheckInterval(interval);
    });
}

// האזנה לאירועי התראות
chrome.alarms.onAlarm.addListener((alarm) => {
    if (alarm.name === 'checkNotifications') {
        checkNotificationsBackground();
    }
});

// האזנה ללחיצה על התראת מערכת
chrome.notifications.onClicked.addListener((notificationId) => {
    if (notificationId === 'newNotifications') {
        chrome.windows.create({
            url: 'popup.html',
            type: 'popup',
            width: 400,
            height: 600
        });
        chrome.notifications.clear(notificationId);
    }
});

// הפעלת הבדיקות בהתחלה
chrome.runtime.onStartup.addListener(startBackgroundCheck);
chrome.runtime.onInstalled.addListener(startBackgroundCheck);